/*
 *	Custom SilkScreenArea 
 *	v1.0
 *	April 24. 2001
 *	
 *	by Collin R. Mulliner <palm@mulliner.org>
 *		web: www.mulliner.org/palm
 */

#include "build_silk_res.h"

// number of buttons on maximized silkarea
#define NUM_MAX_BUTTONS 9
// number of buttons on minimized silkarea
#define NUM_MIN_BUTTONS 3


int main(int argc, char **argv)
{
	/*
	 *	this structure defines the 3 areas of the screen when the silkscreenarea is MAXIMIZED
	 *
	 *	! you should not change this !
	 */
	silk_res_type QuarterVGASilk =	{
					 1,
					 'poem',
					 23,
					 3,
					 /* silk area list: 3 elements */
					// x   y    w   h
					   0,  0, 240,240, 'scrn', 0,		// the screen
					/*
					 *  if the y coordinat is bigger then 240 do this
					 *  y_pos = 320 + (y_pos - 240)
					 */		 
					  40,324,  93, 84, 'graf', 0,		// graffiti alpha
					 134,324,  67, 84, 'graf', 1,		// graffiti numeric
					 /* button list: 9 elements */
					 NUM_MAX_BUTTONS
					};

	/*
	 *	this defines the all buttons (like applaunch, find, menu, etc...) when the silkscreenarea is MAXIMIZED
	 */
	PenBtnInfoType ButtonList1[NUM_MAX_BUTTONS] =	{
					/*
					 *  if the y coordinat is bigger then 240 do this
					 *  y_pos = 320 + (y_pos - 240)
					 */		 
					// x   y    w   h  virtual key to send if the button gets tad
					  42,377,  27, 25, vchrKeyboardAlpha,	0, commandKeyMask,
					 172,377,  26, 25, vchrKeyboardNumeric,	0, commandKeyMask,
					   0,322,  40, 38, vchrLaunch,		0, commandKeyMask,
					   0,362,  40, 38, vchrMenu,		0, commandKeyMask,
					 201,322,  39, 38, vchrCalc,		0, commandKeyMask,
	 				 201,362,  39, 38, vchrFind,		0, commandKeyMask,
	 				  42,326,  20, 14, 0x020B,		0, commandKeyMask,	// vchrHardContrast
					 179,326,  19, 14, 0x150B,		0, commandKeyMask,	// volume (vchrTRGHardVolume)
					 126,326,  18, 13, 0x150a,		0, commandKeyMask	// silk toggle
					};


	/*
	 *	this structure defines the 3 areas of the screen when the silkscreenarea is MINIMIZED
	 *
	 *	! you should not change this !
	 */				 
	silk_res_type MinimizedSilk =	{
					 1,
					 'poem',
					 23,
					 3,
					 /* silk area list: 3 elements */
					   0,  0, 240,304, 'scrn', 0,
					// no graffiti areas !
					   0,388,   0,  4, 'graf', 0,
					   0,388,   0,  4, 'graf', 1,
					 /* button list: 3 elements */
					 NUM_MIN_BUTTONS
					};
					
	/*
	 *	this defines the all buttons (like applaunch, find, menu, etc...) when the silkscreenarea is MINIMIZED
	 */				
	PenBtnInfoType ButtonList2[NUM_MIN_BUTTONS] =	{
					// same rules as before
					   0,386,  20, 18, vchrLaunch,	0, commandKeyMask,
					  20,386,  20, 18, vchrMenu,	0, commandKeyMask,
					  40,386, 200, 18, 0x150a,	0, commandKeyMask // silk toggle
				 	};
					   

//  ---------------- don't change anything below this line ----------------

	unsigned char *p;
	int i;
	FILE *fp;

	
	// change byte order
	SWAP2(QuarterVGASilk.one)
	SWAP4(QuarterVGASilk.poem)
	SWAP4(QuarterVGASilk.bytes4)
	SWAP2(QuarterVGASilk.bytes2)
	SWAP2(QuarterVGASilk.screenArea.bounds.topLeft.x)
	SWAP2(QuarterVGASilk.screenArea.bounds.topLeft.y)
	SWAP2(QuarterVGASilk.screenArea.bounds.extent.x)
	SWAP2(QuarterVGASilk.screenArea.bounds.extent.y)
	SWAP4(QuarterVGASilk.screenArea.areaType)
	SWAP2(QuarterVGASilk.screenArea.index)
	SWAP2(QuarterVGASilk.graffitiAreaA.bounds.topLeft.x)
	SWAP2(QuarterVGASilk.graffitiAreaA.bounds.topLeft.y)
	SWAP2(QuarterVGASilk.graffitiAreaA.bounds.extent.x)
	SWAP2(QuarterVGASilk.graffitiAreaA.bounds.extent.y)
	SWAP4(QuarterVGASilk.graffitiAreaA.areaType)
	SWAP2(QuarterVGASilk.graffitiAreaA.index)
	SWAP2(QuarterVGASilk.graffitiAreaN.bounds.topLeft.x)
	SWAP2(QuarterVGASilk.graffitiAreaN.bounds.topLeft.y)
	SWAP2(QuarterVGASilk.graffitiAreaN.bounds.extent.x)
	SWAP2(QuarterVGASilk.graffitiAreaN.bounds.extent.y)
	SWAP4(QuarterVGASilk.graffitiAreaN.areaType)
	SWAP2(QuarterVGASilk.graffitiAreaN.index)
	SWAP2(QuarterVGASilk.buttonList.numButtons)
	
	for (i = 0; i < NUM_MAX_BUTTONS; i++) {
		SWAP2(ButtonList1[i].boundsR.topLeft.x)
		SWAP2(ButtonList1[i].boundsR.topLeft.y)
		SWAP2(ButtonList1[i].boundsR.extent.x)
		SWAP2(ButtonList1[i].boundsR.extent.y)
		SWAP2(ButtonList1[i].asciiCode)
		SWAP2(ButtonList1[i].keyCode)
		SWAP2(ButtonList1[i].modifiers)
	}

	SWAP2(MinimizedSilk.one)
	SWAP4(MinimizedSilk.poem)
	SWAP4(MinimizedSilk.bytes4)
	SWAP2(MinimizedSilk.bytes2)
	SWAP2(MinimizedSilk.screenArea.bounds.topLeft.x)
	SWAP2(MinimizedSilk.screenArea.bounds.topLeft.y)
	SWAP2(MinimizedSilk.screenArea.bounds.extent.x)
	SWAP2(MinimizedSilk.screenArea.bounds.extent.y)
	SWAP4(MinimizedSilk.screenArea.areaType)
	SWAP2(MinimizedSilk.screenArea.index)
	SWAP2(MinimizedSilk.graffitiAreaA.bounds.topLeft.x)
	SWAP2(MinimizedSilk.graffitiAreaA.bounds.topLeft.y)
	SWAP2(MinimizedSilk.graffitiAreaA.bounds.extent.x)
	SWAP2(MinimizedSilk.graffitiAreaA.bounds.extent.y)
	SWAP4(MinimizedSilk.graffitiAreaA.areaType)
	SWAP2(MinimizedSilk.graffitiAreaA.index)
	SWAP2(MinimizedSilk.graffitiAreaN.bounds.topLeft.x)
	SWAP2(MinimizedSilk.graffitiAreaN.bounds.topLeft.y)
	SWAP2(MinimizedSilk.graffitiAreaN.bounds.extent.x)
	SWAP2(MinimizedSilk.graffitiAreaN.bounds.extent.y)
	SWAP4(MinimizedSilk.graffitiAreaN.areaType)
	SWAP2(MinimizedSilk.graffitiAreaN.index)
	SWAP2(MinimizedSilk.buttonList.numButtons)
	
	for (i = 0; i < NUM_MIN_BUTTONS; i++) {
		SWAP2(ButtonList2[i].boundsR.topLeft.x)
		SWAP2(ButtonList2[i].boundsR.topLeft.y)
		SWAP2(ButtonList2[i].boundsR.extent.x)
		SWAP2(ButtonList2[i].boundsR.extent.y)
		SWAP2(ButtonList2[i].asciiCode)
		SWAP2(ButtonList2[i].keyCode)
		SWAP2(ButtonList2[i].modifiers)
	}	
		
	// beginn of real code
		
	fp = fopen(argv[1], "w");
	
	p = (unsigned char*) &QuarterVGASilk;
	
	for (i = 0; i < sizeof(silk_res_type); i++) {
		fprintf(fp, "0x");
		if (*(p+i) < 16) fprintf(fp, "0");
		fprintf(fp, "%X ", *(p+i));
	}
	
	p = (unsigned char*) &ButtonList1;
	
	for (i = 0; i < (sizeof(PenBtnInfoType) * NUM_MAX_BUTTONS); i++) {
		fprintf(fp, "0x");
		if (*(p+i) < 16) fprintf(fp, "0");
		fprintf(fp, "%X ", *(p+i));
	}
		
	fclose(fp);
	

	fp = fopen(argv[2], "w");
	
	p = (unsigned char*) &MinimizedSilk;
	
	for (i = 0; i < sizeof(silk_res_type); i++) {
		fprintf(fp, "0x");
		if (*(p+i) < 16) fprintf(fp, "0");
		fprintf(fp, "%X ", *(p+i));
	}
	
	p = (unsigned char*) &ButtonList2;
	
	for (i = 0; i < (sizeof(PenBtnInfoType) * NUM_MIN_BUTTONS); i++) {
		fprintf(fp, "0x");
		if (*(p+i) < 16) fprintf(fp, "0");
		fprintf(fp, "%X ", *(p+i));
	}
	
	fclose(fp);
}
